@@ -18,7 +18,7 @@ from __future__ import annotations
 #
 # This code may only be used for good, not evil.
 
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 
 import numpy as np
 import jax
@@ -114,7 +114,6 @@ class MappedArray:
             return sorted(range(len(seq)), key=seq.__getitem__)
 
         sorted_indices = argsort(nums)
-        print("sorted_indices", sorted_indices)
         A = self
         for i in reversed(sorted_indices):
             A = A.map_axis(nums[i], names[i])
@@ -570,7 +569,6 @@ def wrap(fun):
             t0 = time.time()
             my_args = [Array(jax_arg) for jax_arg in jax_args]
             t1 = time.time()
-            print("args time", t1-t0)
 
             active_ranges = Range._active_ranges
             Range._active_ranges = {}
@@ -623,7 +621,6 @@ class Slot(Array):
         for ax in Range._active_ranges:
             if ax not in idx:
                 #warnings.warn(f"Active range {ax} not in indices being assigned",UserWarning)
-                print(Range._active_ranges)
                 raise SyntaxError(f"Active range {ax} not in indices being assigned in {dest_str} <- {origin_str}")
 
         num_empty = len([i for i in idx if i == slice(None)])
@@ -890,7 +887,6 @@ class Range:
 # flat and grad
 
 def array_flatten(x: MappedArray):
-    #print(f"flattening {x=}")
     children = (x.data,)
     aux_data = (x.axes,type(x))
     return children, aux_data
